@@ -6,7 +6,7 @@ use HTTP::Headers::Util qw(split_header_words join_header_words);
 use LWP::Debug ();
 
 use vars qw($VERSION $EPOCH_OFFSET);
-$VERSION = "5.810";
+$VERSION = "5.815";
 
 # Legacy: because "use "HTTP::Cookies" used be the ONLY way
 #  to load the class HTTP::Cookies::Netscape.
@@ -214,11 +214,13 @@ sub extract_cookies
 
 	my $set;
 	for $set (@ns_set) {
+            $set =~ s/^\s+//;
 	    my @cur;
 	    my $param;
 	    my $expires;
 	    my $first_param = 1;
 	    for $param (split(/;\s*/, $set)) {
+                next unless length($param);
 		my($k,$v) = split(/\s*=\s*/, $param, 2);
 		if (defined $v) {
 		    $v =~ s/\s+$//;
@@ -235,6 +237,9 @@ sub extract_cookies
 			$expires++;
 		    }
 		}
+                elsif (!$first_param && lc($k) =~ /^(?:version|discard|ns-cookie)/) {
+                    # ignore
+                }
 		else {
 		    push(@cur, $k => $v);
 		}
